export = Helper;
declare class Helper {
    /**
     * Normalize swagger path definition to express notation
     * @param {String} path the API path
     *
     * @public
     * @static
     */
    public static normalizePath(path: string): string;
    /**
     * Allows to retrieve a variable from the configuration or as environment variable, supports
     * both `:` and `_` notation.
     * @param {Environment} environment the configuration container
     * @param {string} key the key for the variable to retrieve
     * @param {any} _default the default value if the variable is nt defined.
     */
    static getVariable(environment: Environment, key: string, _default: any): any;
    /**
     * Ensure that either the value or default value are returned.
     * @param {any} value the value to verify
     * @param {any} the default value to return
     */
    static ensureValue(value: any, _default: any): any;
    static requestHasBody(req: any): any;
    /**
     * Format the response based on the content type defined
     * @returns {String}
     */
    static format(payload: any, contentType: any): string;
    static isAPromise(obj: any): boolean;
    /**
     * Evaluate if an obj is an instance of a type
     *
     * @param {Any} obj the object to be verified
     * @param {Any} type the type the object will be verified against
     * @returns {Boolean} true if obj is instance of type, fasle otherwise
     */
    static instanceOf(obj: Any, type: Any): boolean;
    /**
     * Tests if the provided string is base64
     * @param {string} v the string to test for base64
     * @returns true if the provided string is base64 encoded, false otherwise
     * @public
     * @static
     */
    public static isBase64(v: string): boolean;
    /**
     * Decode a base64 string
     * @param {string} str a string to decode if base64 encoded
     * @returns the decoded string or the string as is
     * @public
     * @static
     */
    public static decodeFromBase64AndParse(str: string): any;
}
declare namespace Helper {
    export { Helper };
}
/**
 * Helper class exposes utility methods
 */
type Helper = any;
//# sourceMappingURL=helper.d.ts.map