export = Response;
declare class Response {
    /**
     * Create a new response object
     *
     * @param {any} payload the payload to return to the client
     * @returns {Response}
     *
     * @static
     * @public
     */
    public static build(payload: any): Response;
    /**
     * @deprecated
     * This method is now deprecated in favour of the Response#build method and will be removed in future releases.
     *
     * Create a new response object
     *
     * @param {Number} status the status code to return to the client
     * @param {any} payload the payload to return to the client
     * @returns {Response}
     *
     * @static
     * @public
     */
    public static builder(_status: any, payload: any): Response;
    /**
     * Create a new response object
     *
     * @param {any} payload the payload to return to the client
     *
     * @private
     */
    private constructor();
    body: any;
    contentType: string;
    headers: {};
    /**
     * Allow to set the response contentType, assumed JSON by default.
     * @param {String} contentType the content type for the response
     */
    setContentType(contentType: string): this;
    /**
     * Allows to set the status code
     * @param {Number} statusCode the status code sent to the client
     *
     * **This method is not supposed to be used directly by the user
     * and is reserved to the framework only.**
     */
    setStatusCode(statusCode: number): this;
    statusCode: number;
    /**
     * Allow to add an header to the response
     * @param {String} name the header name
     * @param {String} value the header value
     */
    addHeader(name: string, value: string): this;
    /**
     * Propagate the response to the client.
     *
     * @param {any} res the express response object
     *
     * **This method is not supposed to be used directly by the user
     * and is reserved to the framework only.**
     */
    propagate(res: any): void;
}
declare namespace Response {
    export { Response };
}
/**
 * The response that is returned from the API handler.
 */
type Response = any;
//# sourceMappingURL=response.d.ts.map