export = RoutingConfigurer;
declare class RoutingConfigurer extends Component {
    constructor({ applicationContext, environment }: {
        applicationContext: any;
        environment: any;
    });
    server: any;
    applicationStateMonitor: ApplicationStateMonitor;
    environment: any;
    applicationContext: any;
    postConstruct(): Promise<void>;
    resolveDescriptorProvider(): any;
    setupMonitoringEndpointsIfRequired(router: any): void;
    /**
     * Allows to define top level monitors. The returned obects contains two arrays
     * before and after middlewares, the before middlewares are added at the very start
     * of the middleware chain while the after are added at the very end of the middleware
     * chain, both in the order that are defined.
     *
     * @returns {Object}
     * ```{
     *    before: [],
     *    after: []
     *  }```
     */
    defineTopLevelMonitorsIfRequired(): any;
    /**
     * Allows to add a monitor
     * @param {Monitor} monitor
     */
    addMonitor(monitor: Monitor): void;
    /**
     * Hook method allow to customize the express instance. by default it add the json middleware only.
     * This method can be overwritten in order to provide more tailored configuration of express instance.
     *
     * @param {any} express the express instance
     * @protected
     */
    protected extend(express: any): void;
    /**
     * Hook allows to provide an express error handler, by default a JSON error handler is used.
     * @protected
     */
    protected errorHandler(): (err: any, req: any, res: any, next: any) => any;
    /**
     * Allows users to provide custom middlewares the middlewares will be inserted on the
     * chain as provided by the user but between the built-in API validation and route
     * handler and error handler.
     * @param {any} api the swagger API definition
     * @param {any} components the components OpenAPI definition
     * @returns {Array<Function>}
     *
     * @protected
     */
    protected middlewares(api: any, components: any): Array<Function>;
    /**
     * Hook allow to define a custom request handler middleware. If no middleware is
     * returned the default will be used.
     * @param {any} api the OpenAPI definition
     * @param {function} responseValidator the validato for the response expected by the OpenAPI definition.
     * @returns {Function}
     *
     * @protected
     */
    protected requestHandler(api: any, responseValidator: Function): Function;
    /**
     * Retrieve the value associated with the key or the default.
     * @param {String} key the key for the value to retrieve
     * @param {any} _default the default value
     *
     * @private
     */
    private getVariable;
    /**
     * Get the cache middleware configured as requested for the current route
     * @param {Aany} cache the cache configuration
     * @returns {Function} the cache middleware.
     *
     * @private
     */
    private getCache;
    /**
     * Define a function that discriminate what responses should be cahced. In this case only responses
     * with 200 response code from GET requests.
     * @returns {Function} the cache toggle function
     *
     * @private
     */
    private cacheOnlySuccessResponsesForGet;
}
declare namespace RoutingConfigurer {
    export { RoutingConfigurer };
}
import Component_1 = require("dino-core/dist/model/component");
import Component = Component_1.Component;
import ApplicationStateMonitor = require("./monitoring/application.state.monitor");
/**
 * Configure express routing based on swagger configuration.
 */
type RoutingConfigurer = any;
//# sourceMappingURL=routing.configurer.d.ts.map