//    Copyright 2018 Quirino Brizi [quirino.brizi@gmail.com]
// 
//    Licensed under the Apache License, Version 2.0 (the "License");
//    you may not use this file except in compliance with the License.
//    You may obtain a copy of the License at
// 
//        http://www.apache.org/licenses/LICENSE-2.0
// 
//    Unless required by applicable law or agreed to in writing, software
//    distributed under the License is distributed on an "AS IS" BASIS,
//    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//    See the License for the specific language governing permissions and
//    limitations under the License.




const errorHandler = require('express-error-handler');

class ErrorHandler {

  /**
   * Allows to get an instance of the error handler
   */
  static instance() {

    return (err, req, res, next) => {
      if(!err.status && err.statusCode) {
        err.status = err.statusCode;
      }

      let handler = errorHandler({
        shutdown: () => { },
        serializer: function (err) {
          var body = {
            status: err.status || err.statusCode,
            message: err.message
          };
          if (errorHandler.isClientError(err.status)) {
            ['code', 'name', 'type', 'details'].forEach(function (prop) {
              if (err[prop]) body[prop] = err[prop];
            });
          }
          return body;
        }
      });
      return handler(err, req, res, next);
    };
  }
}

/**
 * The error handler used to define the express error handling behaviour
 * @typedef ErrorHandler
 * @public
 */
module.exports = ErrorHandler;