//    Copyright 2018 Quirino Brizi [quirino.brizi@gmail.com]
// 
//    Licensed under the Apache License, Version 2.0 (the "License");
//    you may not use this file except in compliance with the License.
//    You may obtain a copy of the License at
// 
//        http://www.apache.org/licenses/LICENSE-2.0
// 
//    Unless required by applicable law or agreed to in writing, software
//    distributed under the License is distributed on an "AS IS" BASIS,
//    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//    See the License for the specific language governing permissions and
//    limitations under the License.




const Monitor = require('dino-core').Monitor;

class ApplicationStateMonitor {

  constructor(applicationContext) {
    this.monitors = [];
    this.applicationContext = applicationContext;
  }

  doMonitor(res) {
    let monitors = this.getApplicationStateMonitors();
    let properties = {'default': [{name: 'status', value: 'UP'}]};
    if(monitors && monitors.length > 0) {
      properties = monitors.reduce((answer, monitor) => { 
        let state = monitor.execute();
        answer[monitor.name()] = Array.from(state.getProperties()).map(entry => { return {name: entry[0], value: entry[1]}; });
        return answer;
      }, properties);
    }
    return res.status(200)
      .type('application/json')
      .send(JSON.stringify(properties));
  }

  getApplicationStateMonitors() {
    if(!this.monitors) {
      try {
        this.monitors.concat(this.applicationContext.resolveAll(Monitor));
      } catch (e) {
        // Ignore, there is no application state monitor defined, we'll use the default behaviour...
      }
    }
    return this.monitors;
  }

  /**
   * Alloes to add a monitor
   * @param {Monitor} monitor 
   */
  addMonitor(monitor) {
    this.monitors.push(monitor);
    return this;
  }

  middleware() {
    // eslint-disable-next-line no-unused-vars
    return (req, res, next) => this.doMonitor.bind(this)(res); 
  }
}

/**
 * The health monitor handler used to define the express error handling behaviour
 * @typedef ApplicationStateMonitor
 * @public
 */
module.exports = ApplicationStateMonitor;