//    Copyright 2018 Quirino Brizi [quirino.brizi@gmail.com]
// 
//    Licensed under the Apache License, Version 2.0 (the "License");
//    you may not use this file except in compliance with the License.
//    You may obtain a copy of the License at
// 
//        http://www.apache.org/licenses/LICENSE-2.0
// 
//    Unless required by applicable law or agreed to in writing, software
//    distributed under the License is distributed on an "AS IS" BASIS,
//    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//    See the License for the specific language governing permissions and
//    limitations under the License.

const { Monitor, State } = require('dino-core');
const { co2 } = require("@tgwf/co2");

class CO2EmissionMonitor extends Monitor {
  
  constructor() {
    super()
    this.properties = new Map();
    this.properties.set('model', '1byte')
    this.properties.set('totalCO2GramsPerByte', 0)
    this.properties.set('requests', {
      total: 0,
      totalCO2GramsPerByteRead: 0 
    })
    this.properties.set('responses', {
      total: 0,
      totalCO2GramsPerByteWritten: 0 
    })
    this.co2EmissionCalculator = new co2({model: '1byte'})
  }
  
  execute() {
    return State.from(this.properties);
  }

  name() {
    return 'CO2 Emissions';
  }

  requestMiddleware(req, _res, next) {
    this._collectRequestInfoRequired(req)
    next()
  }

  responseMiddleware(_req, res, next) {
    this._collectResponseInfoRequired(res)
    next()
  }

  _collectRequestInfoRequired(req) {
    const requests = this.properties.get('requests')
    const co2Emission = this.co2EmissionCalculator.perByte(req.socket.bytesRead)
    requests.total += 1
    requests.totalCO2GramsPerByteRead += co2Emission
    this.properties.set('totalCO2GramsPerByte', this.properties.get('totalCO2GramsPerByte') + co2Emission)
  }

  _collectResponseInfoRequired(res) {
    const responses = this.properties.get('responses')
    const co2Emission = this.co2EmissionCalculator.perByte(res.socket.bytesWritten)
    responses.total += 1
    responses.totalCO2GramsPerByteWritten += co2Emission
    this.properties.set('totalCO2GramsPerByte', this.properties.get('totalCO2GramsPerByte') + co2Emission)
  }
}

module.exports = CO2EmissionMonitor;